aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJosef Spillner <spillner@kde.org>2007-04-02 18:49:17 +0000
committerJosef Spillner <spillner@kde.org>2007-04-02 18:49:17 +0000
commitaee44af17fafa4b5fd76337e809c29b1bfc4fa23 (patch)
tree1b1f9bfc425b71552d4599eebcb5a5b7956cedad
parentabb19d1a121734bb8ddd828daf0ec94a7e023901 (diff)
downloadextra-cmake-modules-aee44af17fafa4b5fd76337e809c29b1bfc4fa23.tar.gz
extra-cmake-modules-aee44af17fafa4b5fd76337e809c29b1bfc4fa23.tar.bz2
- it's called KNS2 now, we want old code to fail on purpose instead of by accident
svn path=/trunk/KDE/kdelibs/; revision=649500
-rw-r--r--modules/FindKDE4Internal.cmake8
1 files changed, 4 insertions, 4 deletions
diff --git a/modules/FindKDE4Internal.cmake b/modules/FindKDE4Internal.cmake
index 1b8f61ab..d5bfcb0d 100644
--- a/modules/FindKDE4Internal.cmake
+++ b/modules/FindKDE4Internal.cmake
@@ -31,7 +31,7 @@
# KDE4_KFILE_LIBRARY - the kfile library
# KDE4_KHTML_LIBRARY - the khtml library
# KDE4_KJS_LIBRARY - the kjs library
-# KDE4_KNEWSTUFF_LIBRARY - the knewstuff library
+# KDE4_KNEWSTUFF2_LIBRARY - the knewstuff2 library
# KDE4_KDEPRINT_LIBRARY - the kdeprint library
# KDE4_KDNSSD_LIBRARY - the kdnssd library
# KDE4_PHONONCORE_LIBRARY - the phononcore library
@@ -59,7 +59,7 @@
# KDE4_KFILE_LIBS - the kfile library and all depending libraries
# KDE4_KHTML_LIBS - the khtml library and all depending libraries
# KDE4_KJS_LIBS - the kjs library and all depending libraries
# KDE4_KNEWSTUFF_LIBS - the knewstuff library and all depending libraries
# KDE4_KDEPRINT_LIBS - the kdeprint library and all depending libraries
# KDE4_KDNSSD_LIBS - the kdnssd library and all depending libraries
# KDE4_KDESU_LIBS - the kdesu library and all depending libraries
@@ -435,8 +435,8 @@ else (_kdeBootStrapping)
find_library(KDE4_KJS_LIBRARY NAMES kjs PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
set(KDE4_KJS_LIBS ${kjs_LIB_DEPENDS} ${KDE4_KJS_LIBRARY} )
- find_library(KDE4_KNEWSTUFF_LIBRARY NAMES knewstuff PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
- set(KDE4_KNEWSTUFF_LIBS ${knewstuff_LIB_DEPENDS} ${KDE4_KNEWSTUFF_LIBRARY} )
+ find_library(KDE4_KNEWSTUFF2_LIBRARY NAMES knewstuff2 PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+ set(KDE4_KNEWSTUFF2_LIBS ${knewstuff2_LIB_DEPENDS} ${KDE4_KNEWSTUFF2_LIBRARY} )
find_library(KDE4_KDEPRINT_LIBRARY NAMES kdeprint PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
set(KDE4_KDEPRINT_LIBS ${kdeprint_LIB_DEPENDS} ${KDE4_KDEPRINT_LIBRARY} )
@@ -59,7 +59,7 @@
# KDE4_KHTML_LIBS - the khtml library and all depending libraries
# KDE4_KJS_LIBS - the kjs library and all depending libraries
-# KDE4_KNEWSTUFF_LIBS - the knewstuff library and all depending libraries
+# KDE4_KNEWSTUFF2_LIBS - the knewstuff2 library and all depending libraries
# KDE4_KDEPRINT_LIBS - the kdeprint library and all depending libraries
# KDE4_KDNSSD_LIBS - the kdnssd library and all depending libraries